@@ -1,4 +1,4 @@
-(function () {
+(function ($) {
   /**
    * Patch TOC list.
    *
@@ -8,12 +8,14 @@
    * @param minLevel: Starting level for nested lists. (1: global, 2: local).
    */
   var patchToc = function ($ul, minLevel) {
-    var findA;
+    var findA,
+      patchTables,
+      $localLi;
 
     // Find all a "internal" tags, traversing recursively.
     findA = function ($elem, level) {
-      var level = level || 0,
-        $items = $elem.find("> li > a.internal, > ul, > li > ul");
+      level = level || 0;
+      var $items = $elem.find("> li > a.internal, > ul, > li > ul");
 
       // Iterate everything in order.
       $items.each(function (index, item) {
@@ -26,7 +28,7 @@
         if (tag === 'ul' && level >= minLevel && $childrenLi.length > 0) {
           $parentLi
             .addClass('dropdown-submenu')
-            .children('a').first().attr('tabindex', -1)
+            .children('a').first().attr('tabindex', -1);
 
           $item.addClass('dropdown-menu');
         }
@@ -42,7 +44,7 @@
    * Patch all tables to remove ``docutils`` class and add Bootstrap base
    * ``table`` class.
    */
-  var patchTables = function () {
+  patchTables = function () {
     $("table.docutils")
       .removeClass("docutils")
       .addClass("table")
@@ -50,37 +52,46 @@
   };
 
   $(document).ready(function () {
-    // Fix iPhone menu clicks.
-    // From: https://github.com/twitter/bootstrap/issues/4550#issuecomment-8476763
-    $('.dropdown-menu').on('touchstart.dropdown.data-api', function(e) {
-      e.stopPropagation();
-    });
-    // See also...
-    // // From: https://github.com/twitter/bootstrap/issues/4550#issuecomment-8879600
-    // $('a.dropdown-toggle, .dropdown-menu a').on('touchstart', function(e) {
-    //   e.stopPropagation();
-    // });
-
     // Add styling, structure to TOC's.
     $(".dropdown-menu").each(function () {
       $(this).find("ul").each(function (index, item){
         var $item = $(item);
         $item.addClass('unstyled');
       });
-      $(this).find("li").each(function () {
-        $(this).parent().append(this);
-      });
     });
 
-    // Patch in level.
-    patchToc($("ul.globaltoc"), 1);
+    // Global TOC.
+    if ($("ul.globaltoc li").length) {
+      patchToc($("ul.globaltoc"), 1);
+    } else {
+      // Remove Global TOC.
+      $(".globaltoc-container").remove();
+    }
+
+    // Local TOC.
     patchToc($("ul.localtoc"), 2);
 
-    // Add divider to local TOC if more children after.
-    if ($("ul.localtoc > ul > li > ul li").length > 0) {
-      $("ul.localtoc > ul > li > a")
-        .first()
-        .after('<li class="divider"></li>');
+    // Mutate sub-lists (for bs-2.3.0).
+    $(".dropdown-menu ul").not(".dropdown-menu").each(function () {
+      var $ul = $(this),
+        $parent = $ul.parent(),
+        tag = $parent[0].tagName.toLowerCase(),
+        $kids = $ul.children().detach();
+
+      // Replace list with items if submenu header.
+      if (tag === "ul") {
+        $ul.replaceWith($kids);
+      } else if (tag === "li") {
+        // Insert into previous list.
+        $parent.after($kids);
+        $ul.remove();
+      }
+    });
+
+    // Add divider in page TOC.
+    $localLi = $("ul.localtoc li");
+    if ($localLi.length > 2) {
+      $localLi.first().after('<li class="divider"></li>');
     }
 
     // Enable dropdown.
@@ -94,8 +105,8 @@
     $('div.warning').addClass('alert');
 
     // Inline code styles to Bootstrap style.
-    $('tt.docutils span.pre').replaceWith(function () {
+    $('tt.docutils').replaceWith(function () {
       return $("<code />").text($(this).text());
-    })
+    });
   });
-}());
+}($jqTheme || window.jQuery));
